@@ -2,15 +2,9 @@ from typing import Tuple, List
 from math import fabs
 from collections import namedtuple
 import logging
-from pathlib import Path
-import sys
 
-PROJECT_ROOT_DIR = Path(__file__).parent.parent
-if str(PROJECT_ROOT_DIR.absolute()) not in sys.path:
-    sys.path.append(str(PROJECT_ROOT_DIR.absolute()))
-
-from utils_common.attitude_angle_calc_utils import RollDirection, get_roll_direction, get_roll_deg
-from terminations.termination_base import TerminationBase
+from flycraft.utils_common.attitude_angle_calc_utils import RollDirection, get_roll_direction, get_roll_deg
+from flycraft.terminations.termination_base import TerminationBase
 
 
 class ContinuouselyRollTermination(TerminationBase):
