@@ -1,15 +1,9 @@
 from typing import Tuple, List
 from collections import namedtuple
 import logging
-from pathlib import Path
-import sys
 
-PROJECT_ROOT_DIR = Path(__file__).parent.parent
-if str(PROJECT_ROOT_DIR.absolute()) not in sys.path:
-    sys.path.append(str(PROJECT_ROOT_DIR.absolute()))
-
-from terminations.termination_base import TerminationBase
-from utils_common.geometry_utils import angle_of_2_velocity
+from flycraft.terminations.termination_base import TerminationBase
+from flycraft.utils_common.geometry_utils import angle_of_2_velocity
 
 
 class ReachTargetTerminationSingleStep(TerminationBase):
